@@ -25,9 +25,9 @@ class LazyVal:
     """
     >>> lazies = []
     >>> f = lambda l: {"y":1, "z":2}
-    >>> deps = {"l":LazyVal("y", f, {"l":0}, None)}
-    >>> a = LazyVal("y", f, deps, lazies)
-    >>> b = LazyVal("z", f, deps, lazies)
+    >>> deps = {"l":LazyVal("y", f, {"l":0}, {"l":0}, None)}
+    >>> a = LazyVal("y", f, deps, deps, lazies)
+    >>> b = LazyVal("z", f, deps, deps, lazies)
     >>> lazies.extend([a, b])
     >>> a
     →(l→(l))
@@ -41,9 +41,10 @@ class LazyVal:
     2
     """
 
-    def __init__(self, field, f, deps, lazies):
+    def __init__(self, field, f, deps, data, lazies):
         self.field = field
         self.f = f
+        self.data = data
         self.deps = deps
         self.lazies = lazies
         self.result = None
@@ -53,6 +54,8 @@ class LazyVal:
             for k, v in self.deps.items():
                 if isinstance(v, LazyVal):
                     self.deps[k] = v()
+                    if k in self.data:
+                        self.data[k] = self.deps[k]
             ret = self.f(**self.deps)
             if self.lazies is None:
                 self.result = ret
